@@ -7,7 +7,7 @@
 -- |
 -- Module      : Test.Hspec.BenchGolden.Runner
 -- Description : Benchmark execution and golden file comparison
--- Copyright   : (c) 2026
+-- Copyright   : (c) Marco Zocca 2026
 -- License     : MIT
 -- Maintainer  : @ocramz
 --
@@ -15,10 +15,10 @@
 -- golden files. It includes:
 --
 -- * Benchmark execution with warm-up iterations
--- * Golden file I/O (reading/writing JSON statistics)
+-- * Golden file IO (reading and writing JSON statistics)
 -- * Tolerance-based comparison with variance warnings
 -- * Support for updating baselines via GOLDS_GYM_ACCEPT environment variable
--- * Evaluation strategies to control how values are forced (nf, whnf, etc.)
+-- * Evaluation strategies to control how values are forced (nf variants).
 --
 -- = Evaluation Strategies
 --
@@ -26,14 +26,11 @@
 -- optimizing away computations or sharing results across iterations:
 --
 -- * 'nf' - Force result to normal form (deep, full evaluation)
--- * 'whnf' - Force result to weak head normal form (shallow evaluation)
 -- * 'nfIO' - Execute IO and force result to normal form
--- * 'whnfIO' - Execute IO and force result to WHNF
 -- * 'nfAppIO' - Apply function, execute IO, force result to normal form
--- * 'whnfAppIO' - Apply function, execute IO, force result to WHNF
 -- * 'io' - Plain IO without additional forcing
 --
--- These are vendored from tasty-bench with proper attribution (BSD-3-Clause).
+-- These are vendored from tasty-bench under the MIT license, (c) 2021 Andrew Lelechenko.
 
 module Test.Hspec.BenchGolden.Runner
   ( -- * Running Benchmarks
@@ -68,11 +65,8 @@ module Test.Hspec.BenchGolden.Runner
     -- * Benchmarkable Constructors
   , io
   , nf
-  , whnf
   , nfIO
-  , whnfIO
   , nfAppIO
-  , whnfAppIO
   ) where
 
 import Control.DeepSeq (NFData, rnf)
@@ -100,19 +94,12 @@ import Test.Hspec.BenchGolden.Arch (detectArchitecture, sanitizeForFilename)
 import Test.Hspec.BenchGolden.Lenses (metricFor, varianceFor)
 import Test.Hspec.BenchGolden.Types
 
--- -----------------------------------------------------------------------------
--- Evaluation Strategies
--- Vendored from tasty-bench-0.5 with modifications
--- Copyright (c) 2021 Andrew Lelechenko and tasty-bench contributors
--- MIT License
--- https://hackage.haskell.org/package/tasty-bench-0.5
--- -----------------------------------------------------------------------------
-
 -- | Benchmark a pure function applied to an argument, forcing the result to
 -- normal form (NF) using 'rnf' from "Control.DeepSeq".
 -- This ensures the entire result structure is evaluated.
 --
 -- Example:
+--
 -- @
 -- benchGolden "fib 30" (nf fib 30)
 -- @
@@ -120,20 +107,10 @@ nf :: NFData b => (a -> b) -> a -> BenchAction
 nf = funcToBench rnf
 {-# INLINE nf #-}
 
--- | Benchmark a pure function applied to an argument, forcing the result to
--- weak head normal form (WHNF) only. This evaluates just the outermost constructor.
---
--- Example:
--- @
--- benchGolden "replicate" (whnf (replicate 1000) 42)
--- @
-whnf :: (a -> b) -> a -> BenchAction
-whnf = funcToBench id
-{-# INLINE whnf #-}
-
 -- | Benchmark an 'IO' action, forcing the result to normal form.
 --
 -- Example:
+--
 -- @
 -- benchGolden "readFile" (nfIO $ readFile "data.txt")
 -- @
@@ -141,19 +118,10 @@ nfIO :: NFData a => IO a -> BenchAction
 nfIO = ioToBench rnf
 {-# INLINE nfIO #-}
 
--- | Benchmark an 'IO' action, forcing the result to weak head normal form.
---
--- Example:
--- @
--- benchGolden "getLine" (whnfIO getLine)
--- @
-whnfIO :: IO a -> BenchAction
-whnfIO = ioToBench id
-{-# INLINE whnfIO #-}
-
 -- | Benchmark a function that performs 'IO', forcing the result to normal form.
 --
 -- Example:
+--
 -- @
 -- benchGolden "lookup in map" (nfAppIO lookupInDB "key")
 -- @
@@ -161,20 +129,11 @@ nfAppIO :: NFData b => (a -> IO b) -> a -> BenchAction
 nfAppIO = ioFuncToBench rnf
 {-# INLINE nfAppIO #-}
 
--- | Benchmark a function that performs 'IO', forcing the result to weak head normal form.
---
--- Example:
--- @
--- benchGolden "query database" (whnfAppIO queryDB params)
--- @
-whnfAppIO :: (a -> IO b) -> a -> BenchAction
-whnfAppIO = ioFuncToBench id
-{-# INLINE whnfAppIO #-}
-
 -- | Benchmark an 'IO' action, discarding the result.
 -- This is for backward compatibility with code that uses @IO ()@ actions.
 --
 -- Example:
+-- 
 -- @
 -- benchGolden "compute" (io $ do
 --   result <- heavyComputation
